@@ -101,7 +101,12 @@ def test_full_join(
     assert_equal_data(result, expected)
 
 
-def test_full_join_duplicate(constructor: Constructor) -> None:
+def test_full_join_duplicate(
+    request: pytest.FixtureRequest, constructor: Constructor
+) -> None:
+    if "ibis" in str(constructor):
+        request.applymarker(pytest.mark.xfail)
+
     df1 = {"foo": [1, 2, 3], "val1": [1, 2, 3]}
     df2 = {"foo": [1, 2, 3], "foo_right": [1, 2, 3]}
     df_left = nw.from_native(constructor(df1)).lazy()
@@ -506,7 +511,9 @@ def test_joinasof_numeric(
 ) -> None:
     if any(x in str(constructor) for x in ("pyarrow_table", "cudf", "pyspark")):
         request.applymarker(pytest.mark.xfail)
-    if "duckdb" in str(constructor) and strategy == "nearest":
+    if (
+        "duckdb" in str(constructor) or "ibis" in str(constructor)
+    ) and strategy == "nearest":
         request.applymarker(pytest.mark.xfail)
     if PANDAS_VERSION < (2, 1) and (
         ("pandas_pyarrow" in str(constructor)) or ("pandas_nullable" in str(constructor))
@@ -578,7 +585,9 @@ def test_joinasof_time(
 ) -> None:
     if any(x in str(constructor) for x in ("pyarrow_table", "cudf", "pyspark")):
         request.applymarker(pytest.mark.xfail)
-    if "duckdb" in str(constructor) and strategy == "nearest":
+    if (
+        "duckdb" in str(constructor) or "ibis" in str(constructor)
+    ) and strategy == "nearest":
         request.applymarker(pytest.mark.xfail)
     if PANDAS_VERSION < (2, 1) and ("pandas_pyarrow" in str(constructor)):
         request.applymarker(pytest.mark.xfail)
@@ -811,6 +820,9 @@ def test_join_duplicate_column_names(
         exception = AnalysisException
     elif "modin" in str(constructor):
         exception = NotImplementedError
+    elif "ibis" in str(constructor):
+        # ibis doesn't raise here
+        request.applymarker(pytest.mark.xfail)
     else:
         exception = nw.exceptions.DuplicateError
     df = constructor({"a": [1, 2, 3, 4, 5], "b": [6, 6, 6, 6, 6]})
